==> haskell-hedgehog-classes-0.2.5.4-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hedgehog-classes
version:              0.2.5.4
visibility:           public
id:                   hedgehog-classes-0.2.5.4-I0fOmzaIcn8DEckAuWidFt
key:                  hedgehog-classes-0.2.5.4-I0fOmzaIcn8DEckAuWidFt
license:              BSD-3-Clause
copyright:            2020 chessai
maintainer:           chessai1996@gmail.com
author:               chessai
homepage:             https://github.com/hedgehogqa/haskell-hedgehog-classes
synopsis:             Hedgehog will eat your typeclass bugs
description:
    This library provides Hedgehog properties to ensure
    that typeclass instances adhere to the set of laws
    that they are supposed to. There are other libraries
    that do similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing any
    new typeclasses that the user needs to learn, and otherwise minimal
    API overhead.

    This library is directly inspired by `quickcheck-classes`.

category:             Testing
abi:                  522e80bb325dc9d74a91bc0992ff7c23
exposed:              True
exposed-modules:      Hedgehog.Classes
hidden-modules:
    Hedgehog.Classes.Alternative Hedgehog.Classes.Applicative
    Hedgehog.Classes.Arrow Hedgehog.Classes.Bifoldable
    Hedgehog.Classes.Bifunctor Hedgehog.Classes.Binary
    Hedgehog.Classes.Bitraversable Hedgehog.Classes.Bits
    Hedgehog.Classes.Category Hedgehog.Classes.Common
    Hedgehog.Classes.Common.ApTrans Hedgehog.Classes.Common.Bottom
    Hedgehog.Classes.Common.Compat Hedgehog.Classes.Common.Equation
    Hedgehog.Classes.Common.Func Hedgehog.Classes.Common.Gen
    Hedgehog.Classes.Common.IO Hedgehog.Classes.Common.Laws
    Hedgehog.Classes.Common.Property Hedgehog.Classes.Common.PP
    Hedgehog.Classes.Comonad Hedgehog.Classes.Contravariant
    Hedgehog.Classes.Enum Hedgehog.Classes.Eq Hedgehog.Classes.Foldable
    Hedgehog.Classes.Functor Hedgehog.Classes.Generic
    Hedgehog.Classes.Integral Hedgehog.Classes.Json
    Hedgehog.Classes.Monad Hedgehog.Classes.MonadIO
    Hedgehog.Classes.MonadPlus Hedgehog.Classes.MonadZip
    Hedgehog.Classes.Monoid Hedgehog.Classes.MVector
    Hedgehog.Classes.Ord Hedgehog.Classes.Prim
    Hedgehog.Classes.Semigroup Hedgehog.Classes.Semiring
    Hedgehog.Classes.Show Hedgehog.Classes.ShowRead
    Hedgehog.Classes.Storable Hedgehog.Classes.Traversable

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hedgehog-classes-0.2.5.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hedgehog-classes-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog-classes
hs-libraries:         HShedgehog-classes-0.2.5.4-I0fOmzaIcn8DEckAuWidFt
depends:
    aeson-2.1.2.1-Explt7i9hRWCBVvHGUB5A2 base-4.16.4.0 binary-0.8.9.0
    comonad-5.0.8-84b3BezuKhZBFe3aAOK7zo containers-0.6.5.1
    hedgehog-1.2-I9IyB1h7sDn9Uxr3yTYmGm
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy
    primitive-0.7.4.0-FVB8RLw7kwa2mbgh0KVHMG
    semirings-0.6-ET8O6is6JMgKSuIPmX2Dlm
    silently-1.2.5.3-ELa4xfIWJNsGKlyJ7FNmrT transformers-0.5.6.2
    vector-0.13.1.0-G7FmTKS6EuOC4CxSRTf251
    wl-pprint-annotated-0.1.0.1-BIQiMOGn9EQ8at820qV3Af

haddock-interfaces:
    /usr/share/doc/haskell-hedgehog-classes/html/hedgehog-classes.haddock

haddock-html:         /usr/share/doc/haskell-hedgehog-classes/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-classes-0.2.5.4-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hedgehog-classes
version:              0.2.5.4
visibility:           public
id:                   hedgehog-classes-0.2.5.4-8Acp8gqeYgzEph5hKaW16
key:                  hedgehog-classes-0.2.5.4-8Acp8gqeYgzEph5hKaW16
license:              BSD-3-Clause
copyright:            2020 chessai
maintainer:           chessai1996@gmail.com
author:               chessai
homepage:             https://github.com/hedgehogqa/haskell-hedgehog-classes
synopsis:             Hedgehog will eat your typeclass bugs
description:
    This library provides Hedgehog properties to ensure
    that typeclass instances adhere to the set of laws
    that they are supposed to. There are other libraries
    that do similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing any
    new typeclasses that the user needs to learn, and otherwise minimal
    API overhead.

    This library is directly inspired by `quickcheck-classes`.

category:             Testing
abi:                  20c8bd9b5cfdcc6b40b07ef477d2892a
exposed:              True
exposed-modules:      Hedgehog.Classes
hidden-modules:
    Hedgehog.Classes.Alternative Hedgehog.Classes.Applicative
    Hedgehog.Classes.Arrow Hedgehog.Classes.Bifoldable
    Hedgehog.Classes.Bifunctor Hedgehog.Classes.Binary
    Hedgehog.Classes.Bitraversable Hedgehog.Classes.Bits
    Hedgehog.Classes.Category Hedgehog.Classes.Common
    Hedgehog.Classes.Common.ApTrans Hedgehog.Classes.Common.Bottom
    Hedgehog.Classes.Common.Compat Hedgehog.Classes.Common.Equation
    Hedgehog.Classes.Common.Func Hedgehog.Classes.Common.Gen
    Hedgehog.Classes.Common.IO Hedgehog.Classes.Common.Laws
    Hedgehog.Classes.Common.Property Hedgehog.Classes.Common.PP
    Hedgehog.Classes.Comonad Hedgehog.Classes.Contravariant
    Hedgehog.Classes.Enum Hedgehog.Classes.Eq Hedgehog.Classes.Foldable
    Hedgehog.Classes.Functor Hedgehog.Classes.Generic
    Hedgehog.Classes.Integral Hedgehog.Classes.Json
    Hedgehog.Classes.Monad Hedgehog.Classes.MonadIO
    Hedgehog.Classes.MonadPlus Hedgehog.Classes.MonadZip
    Hedgehog.Classes.Monoid Hedgehog.Classes.MVector
    Hedgehog.Classes.Ord Hedgehog.Classes.Prim
    Hedgehog.Classes.Semigroup Hedgehog.Classes.Semiring
    Hedgehog.Classes.Show Hedgehog.Classes.ShowRead
    Hedgehog.Classes.Storable Hedgehog.Classes.Traversable

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hedgehog-classes-0.2.5.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hedgehog-classes-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog-classes
hs-libraries:         HShedgehog-classes-0.2.5.4-8Acp8gqeYgzEph5hKaW16
depends:
    aeson-2.1.2.1-8ueLuG1qYj9Fbt4mgkSEM3 base-4.16.4.0 binary-0.8.9.0
    comonad-5.0.8-Eky328ZCag5CAyHmtRF67N containers-0.6.5.1
    hedgehog-1.2-2JjuPTBJYzR4k51ORigDUC
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy
    primitive-0.7.4.0-AA8L6ftl9K2CnnGUysF0H7
    semirings-0.6-EwwcelRXInyDFSlYfay8D5
    silently-1.2.5.3-ELa4xfIWJNsGKlyJ7FNmrT transformers-0.5.6.2
    vector-0.13.1.0-IsxGr1wjc8yHuZdiqe6rZF
    wl-pprint-annotated-0.1.0.1-66ZhFgfRrRUAGSZbuPGfPp

haddock-interfaces:
    /usr/share/doc/haskell-hedgehog-classes/html/hedgehog-classes.haddock

haddock-html:         /usr/share/doc/haskell-hedgehog-classes/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
